@@ -82,7 +82,11 @@ class HttpHeaders(CaseInsensitiveDict):
     @staticmethod
     def _clear_line(line: bytes):
         """Clear readed line."""
-        return line.rstrip().split(b': ', 1)
+        decoded = line.rstrip().decode()
+        pair = decoded.split(': ', 1)
+        if len(pair) < 2:
+            return decoded.split(':')
+        return pair
 
 
 #: Headers
@@ -152,7 +156,7 @@ class HttpResponse:
             raise HttpParsingError('response line parsing error')
         self.response_initial = res.groupdict()
 
-    def _set_header(self, key: bytes, val: bytes):
+    def _set_header(self, key: str, val: str):
         """Set header to response."""
         self.headers[key] = val
         self.raw_headers.append((key, val))
@@ -163,13 +167,13 @@ class HttpResponse:
             self._set_header(*header_tuple)
 
             # set cookies in response
-            if header_tuple[0].lower() == b'set-cookie':
+            if header_tuple[0].lower() == 'set-cookie':
                 self._update_cookies(header_tuple)
 
     def _update_cookies(self, header_tuple):
         """Update jar of cookies."""
         self.cookies = self.cookies or cookies.SimpleCookie()
-        self.cookies.load(header_tuple[1].decode())
+        self.cookies.load(header_tuple[1])
 
     def _set_connection(self, connection: Connection):
         """Set header to response."""
@@ -182,9 +186,9 @@ class HttpResponse:
 
     def _set_body(self, data):
         """Set body."""
-        if self.compressed == b'gzip':
+        if self.compressed == 'gzip':
             self.body += gzip_decompress(data)
-        elif self.compressed == b'deflate':
+        elif self.compressed == 'deflate':
             self.body += zlib_decompress(data)
         else:
             self.body += data
@@ -260,6 +264,8 @@ def _get_header_data(url: ParseResult,
                      boundary: str = None) -> Union[bytes, HeadersType]:
     """Prepare get data."""
     path = url.path or '/'
+    if url.query:
+        path += '?' + url.query
     http2conn = connection.h2conn
 
     if params:
@@ -442,10 +448,10 @@ async def _do_request(urlparsed: ParseResult,
 
         await response._set_response_headers(_parse_headers_iterator(connection))
 
-        size = response.headers.get(b'content-length')
-        chunked = response.headers.get(b'transfer-encoding', '') == b'chunked'
-        keepalive = b'close' not in response.headers.get(b'connection', b'')
-        response.compressed = response.headers.get(b'content-encoding', '')
+        size = response.headers.get('content-length')
+        chunked = response.headers.get('transfer-encoding', '') == 'chunked'
+        keepalive = 'close' not in response.headers.get('connection', '')
+        response.compressed = response.headers.get('content-encoding', '')
 
         if size:
             response._set_body(await connection.reader.readexactly(int(size)))
@@ -703,7 +709,7 @@ class HTTPClient:
 
         max_redirects = 30
         # if class or request method has false, it will be false
-        verify_ssl = verify and self.verify_ssl 
+        verify_ssl = verify and self.verify_ssl
         while True:
             headers_data = partial(_get_header_data,
                                    url=urlparsed,
@@ -733,7 +739,7 @@ class HTTPClient:
                             urlparsed.hostname, headers)
 
                     parsed_full_url = _get_url_parsed(
-                        response.headers[b'location'].decode())
+                        response.headers['location'])
 
                     # if full url, will have scheme
                     if parsed_full_url.scheme:
@@ -742,7 +748,7 @@ class HTTPClient:
                         urlparsed = _get_url_parsed(
                             url.replace(
                                 urlparsed.path,
-                                response.headers[b'location'].decode()))
+                                response.headers['location']))
                 else:
                     return response
             except ConnectTimeout:
